@@ -30,7 +30,7 @@ class Meta:
 class modelMeta(type):
     def __new__(cls, name, bases, dct):
         attrs = {'mapping': {}, 'Meta': Meta, '__exit__': __exit__, 'readLine': readLine,
-                 'close': close, '__initExcelHandle__': __initExcelHandle__, 'rows': rows, 'getCount': getCount, '_translateMode': _translateMode}
+                 'close': close, '__initExcelHandle__': __initExcelHandle__, 'rows': rows, 'getCount': getCount, '_translateMode': _translateMode, '__rowsCount__': 0}
         for name, value in dct.items():
             if (not isinstance(dct[name], type)) and (not isinstance(dct[name], FunctionType)):
                 if not name.startswith('__'):
@@ -61,20 +61,33 @@ def __initExcelHandle__(self):
                 self.Meta.extension = 'csv'
                 self.__excelHandle__ = open(self.Meta.file)
                 self.__sheetHandle__ = csv.reader(self.__excelHandle__)
-                m_offset= 1
-                while True:
-                    v= next(self.__sheetHandle__)
+                self.__excelHandle__ = None
+                m_offset = 1
+                for v in self.__sheetHandle__:
                     if v:
-                        if m_offset<self.__record_offset:
-                            m_offset+=1
+                        if m_offset < self.__record_offset__:
+                            m_offset += 1
                             continue
                         self.__rows__.append(self._translateMode(v))
                     else:
                         break
+                self.__rowsCount__ = len(self.__rows__)
             elif m_extension == 'xlsx' or m_extension == 'xls':
                 self.Meta.extension = 'xlsx'
                 self.__excelHandle__ = load_workbook(self.Meta.file)
                 self.__sheetHandle__ = self.__excelHandle__[self.Meta.sheet]
+                column = self.__sheetHandle__.max_column+1
+                m_offset= 1
+                tmp_handle= self.__sheetHandle__
+                for m_rows in tmp_handle:
+                    if m_offset < self.__record_offset__:
+                        m_offset += 1
+                        continue
+                    self.__rows__.append(self._translateMode(m_rows))
+                self.__rowsCount__ = len(self.__rows__)
+                tmp_handle= None
+            else:
+                raise Exception('file extension is error.')
         else:
             raise Exception('meta file is None.')
     except Exception as e:
@@ -82,17 +95,29 @@ def __initExcelHandle__(self):
 
 
 def _translateMode(self, data=[]):
+    m_extension = self.Meta.file.rsplit('.')[1].lower()
     if data:
         try:
+            # 关闭IO，然后返回深拷贝对象解决数组里对象值引用引起的所有对象同样的值.
+            # (没搞明白，为什么这里设为NONE了。外层的for循环还能继续下去)
+            self.__sheetHandle__ = None
+            self.__excelHandle__ = None
             for (name, value) in self.mapping.items():
                 if value <= len(data):
-                    attr_value = data[value-1]
+                    if m_extension == 'csv':
+                        attr_value = data[value-1]
+                    elif m_extension == 'xlsx' or m_extension == 'xls':
+                        attr_value= data[value-1].value
+                    else:
+                        raise Exception('file extension is error.')
+                    if not attr_value:
+                        attr_value = '0.00'
                     if attr_value == 'None':
                         attr_value = '0.00'
                     setattr(self, name, attr_value)
                 else:
                     raise Exception('mapping error:(%s,%s)' % (name, value))
-            return self
+            return copy.deepcopy(self)
         except Exception as e:
             raise e
     else:
@@ -109,70 +134,15 @@ def close(self):
 
 
 def getCount(self):
+    return self.__rowsCount__
+
+
+def rows(self):
     return self.__rows__
 
 
-def rows(self, offset=1):
-    m_datas = []
-    m_offset = offset
-    while True:
-        m_ret = self.readLine(m_offset)
-        if m_ret:
-            m_datas.append(m_ret)
-        else:
-            break
-        m_offset += 1
-    return m_datas
-
-
-def readLine(self, lineOffset=1):
-    if lineOffset < 1:
-        lineOffset = 1
-    if self.__sheetHandle__:
-        if self.Meta.extension == 'xlsx':
-            if lineOffset <= self.__sheetHandle__.max_row:
-                rowdata = []
-                column = self.__sheetHandle__.max_column+1
-                for i in range(1, column):
-                    cellvalue = self.__sheetHandle__.cell(
-                        row=lineOffset, column=i).value
-                    rowdata.append(cellvalue)
-                for (name, value) in self.mapping.items():
-                    if value <= len(rowdata):
-                        setattr(self, name, rowdata[value-1])
-                    else:
-                        raise Exception('mapping error:(%s,%s)' %
-                                        (name, value))
-                self.__recordOffset__ = lineOffset
-                return self
-            else:
-                return None
-        else:
-            rowdata = []
-
-            if lineOffset <= self.__recordOffset__:
-                self.__recordOffset__ = lineOffset-1
-            for offset in range(self.__recordOffset__, lineOffset):
-                try:
-                    rowdata = next(self.__sheetHandle__)
-                except Exception as e:
-                    rowdata = []
-            self.__recordOffset__ += 1
-            if rowdata:
-                try:
-                    for (name, value) in self.mapping.items():
-                        if value <= len(rowdata):
-                            attr_value = rowdata[value-1]
-                            if attr_value == 'None':
-                                attr_value = '0.00'
-                            setattr(self, name, attr_value)
-                        else:
-                            raise Exception(
-                                'mapping error:(%s,%s)' % (name, value))
-                    return self
-                except Exception as e:
-                    raise e
-            else:
-                return None
-    else:
-        raise Exception('Sheet Handle is None.')
+def readLine(self, lineOffset=0):
+    if lineOffset >= self.getCount():
+        return None
+    self.__read_offset__= lineOffset
+    return self.__rows__[lineOffset]
