@@ -1,4 +1,18 @@
+#!/usr/bin/env python3.6
+# -*- encoding: utf-8 -*-
+'''
+@File    :   recursion.py
+@Time    :   2020/01/16 23:06:51
+@Author  :   Tang Jing 
+@Version :   1.0.0
+@Contact :   yeihizhi@163.com
+@License :   (C)Copyright 2020
+@Desc    :   None
+'''
+
+# here put the import lib
 import functools
+# code start
 
 def recursion(func):
     def wapper(*args, **kwargs):
@@ -23,14 +37,18 @@ def recursionCall(func, upper_limit:int=200, *args, **wargs):
             break
     return args, wargs
 
-@recursion
-def gggd(*args, **kwargs):
-    print(kwargs['count'])  
-    if kwargs['count'] == 3000:
-        kwargs['break']= True
-        return args, kwargs
-    return gggd(*args, **kwargs)
+
     
 if __name__ == "__main__":
-    eee=recursionCall(gggd)
+    @recursion
+    def gggd(*args, **kwargs):
+        if kwargs['bbb'] == 3001:
+            kwargs['break']= True
+            return args, kwargs
+        print(kwargs['bbb'])
+        kwargs['bbb']+=1
+        return gggd(*args, **kwargs)
+        
+    kwargs={'bbb':1}
+    eee=recursionCall(gggd,**kwargs)
     eeee=""
\ No newline at end of file
